import gymnasium as gym

from stable_baselines3 import A2C
import wandb
from wandb.integration.sb3 import WandbCallback
from huggingface_sb3 import package_to_hub


# from documentation of wandb
config = {
    "policy_type": "MlpPolicy",
    "total_timesteps": 25000,
    "env_name": "CartPole-v1",
}
run = wandb.init(
    project="sb3",
    config=config,
    sync_tensorboard=True,
    monitor_gym=True,
    save_code=True,
)


# from documentation
env = gym.make("CartPole-v1", render_mode="rgb_array")

model = A2C("MlpPolicy", env, verbose=1, tensorboard_log=f"runs/{run.id}")
model.learn(total_timesteps=10_000, callback=WandbCallback(gradient_save_freq=100,model_save_path=f"models/{run.id}",verbose=2,),)
vec_env = model.get_env()
obs = vec_env.reset()
for i in range(1000):
    action, _state = model.predict(obs, deterministic=True)
    obs, reward, done, info = vec_env.step(action)

run.finish()


# from documentation of huggingface
package_to_hub(model=model, 
               model_name="CartPole-v1",
               model_architecture="A2C",
               env_id="CartPole-v1",
               eval_env=env,
               repo_id="lennartoe/Cartpole-v1",
               commit_message="First commit")