import gymnasium as gym
import torch
from reinforce_cartpole import Policy

# function to evaluate the policy
def eval_policy(eval_length, policy, env):
    # reset the environment and get the initial observation
    observation = env.reset()[0]
    rewards = []

    for step in range(eval_length):
        # sample action from policy
        action_probs = policy(torch.from_numpy(observation).float())
        action = torch.distributions.Categorical(action_probs).sample()
        observation, reward, terminated, truncated, info = env.step(action.numpy())
        rewards.append(reward)
        if terminated or truncated: 
            break
    return sum(rewards)

# create env
env = gym.make("CartPole-v1")

policy = Policy()
# load learned policy
policy.load_state_dict(torch.load('reinforce_cartpole.pth', weights_only=True))
policy.eval()

# max stesps
eval_length = env.spec.max_episode_steps
num_evals = 100
number_of_solves = 0

for eval in range(num_evals):
    sum_reward = eval_policy(eval_length, policy, env)
    # check if reward is greater than 195
    if sum_reward >= 195:
        number_of_solves += 1

# compute successrate
success_rate = number_of_solves / num_evals
print(f"Success rate: {success_rate}")

env.close()
